icsemantic.catalog.setuphandlers

Package platecom :: Package ontocatalog :: Module setuphandlers |
[hide private]
[frames] | no frames]

# Module setuphandlers

source code

This module handles the product install process.

Functions | [hide private]
is_icsemantic.catalog_profile(context) Ordinarily, GenericSetup handlers check for the existence of XML files. | source code
add_indexes(context) Add fake catalog indexes for synonyms, translations and relations. | source code
update_portal_atct(context) Update ATCT tool with criteria for synonyms, translations and relations. | source code
install_dependencies(context) Install dependencies | source code
setup_various(context) Basically the install method | source code

Variables | [hide private]
| logger = `logging.getLogger('icsemantic.catalog: setuphandlers')`

Function Details | [hide private]

### is_icsemantic.catalog_profile(context) | source code
Ordinarily, GenericSetup handlers check for the existence of XML files. Here, we are not parsing an XML file, but we use this text file as a flag to check that we actually meant for this import step to be run. The file is found in profiles/default.